
#'
#' A empty method only used to declare some of the global function definitions
#' contained in the package 'methods', which are used intensively.
#'
#' @return no return value
#' @importFrom methods callNextMethod is new show slotNames validObject
#' @keywords internal
methodsGlobalFunctions <- function() {
  
}

#' @importFrom rlang .data :=
#' @keywords internal
rlangGlobal <- function() {
  
}